## 0.4.0 (2026-03-12)

### ✨ Features

- **cz-type**: add revert option

### ➕➖⬆️⬇️ Dependencies

- **pyproject**: upgrade all deps

## 0.3.3 (2025-06-28)

### 🐛🚑️ Fixes

- **dependencies**: add typing-extensions for Python 3.11+

## 0.3.2 (2025-06-14)

### 🐛🚑️ Fixes

- **commitizen**: update bump message constant to follow naming conventions
- **mojify**: fix the regex pattern
- **test**: update test data to match the new format

### ➕➖⬆️⬇️ Dependencies

- **pyproject**: update all dependencies and dev dependencies
- **pyproject**: add ruff and pyright
- **pyproject**: remove mypy and pylint

### 🎨 Style & Architecture

- **lint**: apply all linters to the project

### 🔧 Configuration, Scripts, Packages

- **pyproject**: update pytest and coverage config
- **pyproject**: switch to uv

## 0.3.1 (2024-10-21)

### 🐛🚑️ Fixes

- **changelog**: update the regex and message builder

### ♻️ Refactorings

- test

## 0.3.0 (2024-10-21)

### ✨ Features

- **changelog**: add the chore section

### 🐛🚑️ Fixes

- **pattern**: update the regex

## 0.2.3 (2024-09-19)

### 🐛🚑️ Fixes

- **emoji**: remove trailing whitespaces

## 0.2.2 (2024-09-18)

### 🐛🚑️ Fixes

- **bump**: replace default message by custom with emoji

## 0.2.1 (2024-09-16)

### 🐛🚑️ Fixes

- **commit**: use splitline for body_parser
- **changelog**: change commit_parser

## 0.2.0 (2024-09-16)

### 💚👷 CI & Build

- **deps**: bump codecov/codecov-action from 3 to 4
- **deps**: bump actions/setup-python from 4 to 5
- **deps**: bump actions/checkout from 3 to 4
- **deps**: bump actions/checkout from 2 to 3
- **deps**: bump actions/setup-python from 1 to 4
- **deps**: bump commitizen from 2.38.0 to 2.39.1

### 🔧 Configuration, Scripts, Packages

- update email and version
